@@ -1,8 +1,8 @@
-import insights_python_client
-from insights_python_client import Configuration
+import plotrisk_python_client
+from plotrisk_python_client import Configuration
 
 from python_sdk_client.libs.abstract_client import AbstractClient
-from python_sdk_client.libs.batch_processor import handle
+from python_sdk_client.libs.batch_processor import handle, handleplotdetails
 from python_sdk_client.libs.client_cfg import InsightServiceCfg
 from python_sdk_client.clients_enum import EnvType
 
@@ -40,19 +40,19 @@ class InsightServiceClient(AbstractClient):
 
     def get_plot_details(self, plot_ids: str, **kwargs):
 
-        boundary_api = insights_python_client.PlotApi(insights_python_client.ApiClient(self.configuration))
-        plot_ids_resp = handle(boundary_api.list_all3, plot_ids, self.tenant_type, self.x_api_key, self.org_id,
-                               batch_size=InsightServiceCfg.BATCH_SIZE, **kwargs)
+        boundary_api = plotrisk_python_client.PlotRiskResourceApi(plotrisk_python_client.ApiClient(self.configuration))
+        plot_ids_resp = handleplotdetails(boundary_api.get_plots_using_get,
+                                          batch_size=InsightServiceCfg.BATCH_SIZE, **kwargs)
         return plot_ids_resp
 
     """
-    Validate inputs for satellite details
+    Validate inputs for satellite delist_all3tails
     """
 
     def get_satellite_details(self, plot_ids: str, **kwargs):
 
-        metrics_api = insights_python_client.MetricsApi(insights_python_client.ApiClient(self.configuration))
-        plot_ids_resp = handle(metrics_api.list_all2, plot_ids, self.tenant_type, self.x_api_key, self.org_id,
+        metrics_api = plotrisk_python_client.PlotRiskResourceApi(plotrisk_python_client.ApiClient(self.configuration))
+        plot_ids_resp = handle(metrics_api.get_satellite_using_get, plot_ids,
                                batch_size=InsightServiceCfg.BATCH_SIZE, **kwargs)
         return plot_ids_resp
 
@@ -62,8 +62,8 @@ class InsightServiceClient(AbstractClient):
 
     def get_weather_details(self, plot_ids: str, **kwargs):
 
-        weather_api = insights_python_client.WeatherApi(insights_python_client.ApiClient(self.configuration))
-        weather_api_resp = handle(weather_api.list_all1, plot_ids, self.tenant_type, self.x_api_key, self.org_id,
+        weather_api = plotrisk_python_client.PlotRiskResourceApi(plotrisk_python_client.ApiClient(self.configuration))
+        weather_api_resp = handle(weather_api.get_weather_using_get, plot_ids,
                                   batch_size=InsightServiceCfg.BATCH_SIZE, **kwargs)
         return weather_api_resp
 
@@ -72,8 +72,8 @@ class InsightServiceClient(AbstractClient):
     """
 
     def get_yield_details(self, plot_ids: str, **kwargs):
-        yield_api = insights_python_client.YieldApi(insights_python_client.ApiClient(self.configuration))
-        yield_api_resp = handle(yield_api.list_all, plot_ids, self.tenant_type, self.x_api_key, self.org_id,
+        yield_api = plotrisk_python_client.PlotRiskResourceApi(plotrisk_python_client.ApiClient(self.configuration))
+        yield_api_resp = handle(yield_api.get_yield_using_get, plot_ids,
                                 batch_size=InsightServiceCfg.BATCH_SIZE, **kwargs)
         return yield_api_resp
 
@@ -81,11 +81,9 @@ class InsightServiceClient(AbstractClient):
     Validate inputs for download plot image
     """
 
-    def download_image(self, plot_id: str, image_name, image_type, date):
-        download_api = insights_python_client.FileApi(insights_python_client.ApiClient(self.configuration))
-        file_response = download_api.get_plot_image_for_satellite_and_health_indices(self.tenant_type, self.x_api_key,
-                                                                                     org_id=self.org_id,
-                                                                                     image_type=image_type,
-                                                                                     image_name=image_name, _date=date,
-                                                                                     boundary_id=plot_id)
+    def download_image(self, ca_id: str, image_name, image_type, date):
+        download_api = plotrisk_python_client.PlotRiskResourceApi(plotrisk_python_client.ApiClient(self.configuration))
+        file_response = download_api.download_image_using_get(image_type=image_type,
+                                                              image_name=image_name, _date=date,
+                                                              ca_id=ca_id)
         return file_response
